@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Client::0_90::Direct::Indices;
-$Search::Elasticsearch::Client::0_90::Direct::Indices::VERSION = '6.80';
-use Moo;
+$Search::Elasticsearch::Client::0_90::Direct::Indices::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Client::0_90::Direct::Indices::VERSION = '6.801';use Moo;
 with 'Search::Elasticsearch::Client::0_90::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('indices');
@@ -17,7 +18,7 @@ Search::Elasticsearch::Client::0_90::Direct::Indices - A client for running inde
 
 =head1 VERSION
 
-version 6.80
+version 6.80_1
 
 =head1 DESCRIPTION
 
