@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Client::0_90::Role::API;
-$Search::Elasticsearch::Client::0_90::Role::API::VERSION = '6.80';
-use Moo::Role;
+$Search::Elasticsearch::Client::0_90::Role::API::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Client::0_90::Role::API::VERSION = '6.801';use Moo::Role;
 with 'Search::Elasticsearch::Role::API';
 
 use Search::Elasticsearch::Util qw(throw);
@@ -1185,7 +1186,7 @@ Search::Elasticsearch::Client::0_90::Role::API - This class contains the spec fo
 
 =head1 VERSION
 
-version 6.80
+version 6.80_1
 
 =head1 DESCRIPTION
 
