@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Client::0_90::Role::Bulk;
-$Search::Elasticsearch::Client::0_90::Role::Bulk::VERSION = '6.80';
-use Moo::Role;
+$Search::Elasticsearch::Client::0_90::Role::Bulk::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Client::0_90::Role::Bulk::VERSION = '6.801';use Moo::Role;
 requires 'add_action', 'flush';
 
 use Search::Elasticsearch::Util qw(parse_params throw);
@@ -286,7 +287,7 @@ Search::Elasticsearch::Client::0_90::Role::Bulk - Provides common functionality
 
 =head1 VERSION
 
-version 6.80
+version 6.80_1
 
 =head1 AUTHOR
 
