@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Client::0_90::Scroll;
-$Search::Elasticsearch::Client::0_90::Scroll::VERSION = '6.80';
-use Moo;
+$Search::Elasticsearch::Client::0_90::Scroll::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Client::0_90::Scroll::VERSION = '6.801';use Moo;
 use Search::Elasticsearch::Util qw(parse_params throw);
 use namespace::clean;
 
@@ -126,7 +127,7 @@ Search::Elasticsearch::Client::0_90::Scroll - A helper module for scrolled searc
 
 =head1 VERSION
 
-version 6.80
+version 6.80_1
 
 =head1 SYNOPSIS
 
