@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Client::0_90::TestServer;
-$Search::Elasticsearch::Client::0_90::TestServer::VERSION = '6.80';
-use strict;
+$Search::Elasticsearch::Client::0_90::TestServer::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Client::0_90::TestServer::VERSION = '6.801';use strict;
 use warnings;
 
 #===================================
@@ -42,7 +43,7 @@ Search::Elasticsearch::Client::0_90::TestServer - Client-specific backend for Se
 
 =head1 VERSION
 
-version 6.80
+version 6.80_1
 
 =head1 AUTHOR
 
